@@ -21,7 +21,7 @@ find . -iname '*.o' -delete
 find plugins -iname '*.w?x' -delete
 find plugins -iname '*.dsx' -delete
 find plugins -iname '*.or'  -delete
-find plugins -iname '*.res' -not -path "*/src/*" -delete
+find plugins -iname '*.res' -not -path "*/sevenzip/src/*" -delete
 find plugins -iname '*.a'  -delete
 rm -f src/doublecmd.res doublecmd
 rm -f tools/extractdwrflnfo
